# PyROSALIND
Parsing of [ROSALIND](http://rosalind.info) website, in order to get user information programatically.

To run an example on [aluriak user](http://rosalind.info/users/aluriak), run:

    make

The main script gives example of the main API, which is currently:

    from pyrosalind import User

    aluriak = User.from_name('aluriak')
    print(aluriak)
    print(aluriak.solved)


Use `pip install -r requirements.txt` to install the *beautiful soup* and *requests* dependencies.


## Retrieved data
Input data is the username.

- [X] problems solved
- [ ] badges
- [ ] achievements
- [ ] source codes submitted for each problem
- [ ] scores, statistics
- [ ] global and country ranks
- [ ] account details (last solvel, member for, country, time zone, language)
